pub enum UnsafeBlockSignerUpdateError {
InvalidDataLen(usize),
PointerDecodingError,
InvalidDataPointer(u64),
LengthDecodingError,
InvalidDataLength(u64),
UnsafeBlockSignerAddressDecodingError,
}Expand description
An error for updating the unsafe block signer address on the crate::SystemConfig.
Variants
InvalidDataLen(usize)
Invalid data length.
PointerDecodingError
Failed to decode the data pointer argument from the update log.
InvalidDataPointer(u64)
The data pointer is invalid.
LengthDecodingError
Failed to decode the data length argument from the update log.
InvalidDataLength(u64)
The data length is invalid.
UnsafeBlockSignerAddressDecodingError
Failed to decode the unsafe block signer address argument from the update log.